@@ -452,6 +452,8 @@ class Storage(storage.Storage):
 
         for fact in conflicts:
             # won't eliminate as it is better to have overlapping entries than loosing data
+            if start_time < fact["start_time"] and end_time > fact["end_time"]:
+                continue
 
             # split - truncate until beginning of new entry and create new activity for end
             if fact["start_time"] < start_time < fact["end_time"] and \
@@ -565,7 +567,7 @@ class Storage(storage.Storage):
                 # check if maybe that is the same one, in that case no need to restart
                 if previous["activity_id"] == activity_id \
                    and previous["tags"] == sorted([tag["name"] for tag in tags]) \
-                   and previous["description"] == (description or ""):
+                   and (previous["description"] or "") == (description or ""):
                     return previous["id"]
 
                 # otherwise, if no description is added
@@ -945,7 +947,7 @@ class Storage(storage.Storage):
     def end_transaction(self):
         self.__con.commit()
         self.__cur.close()
-        self.__con = None
+        self.__con, self.__cur = None, None
         self.register_modification()
 
     def run_fixtures(self):
