@@ -21,7 +21,7 @@ import gtk, gobject
 import pango, cairo
 from math import pi
 
-from .. import graphics
+from .. import graphics, stuff
 from ..configuration import runtime
 
 class TagsEntry(gtk.Entry):
@@ -312,16 +312,15 @@ class Tag(graphics.Sprite):
     def __init__(self, text, interactive = True, color = "#F1EAAA"):
         graphics.Sprite.__init__(self, interactive = interactive)
 
-        self.text = text
-
+        self.text = stuff.escape_pango(text)
         font = gtk.Style().font_desc
         font_size = int(font.get_size() * 0.8 / pango.SCALE) # 80% of default
 
-        label = graphics.Label(text, size = font_size, color = (30, 30, 30), y = 2)
+        label = graphics.Label(self.text, size = font_size, color = (30, 30, 30), y = 2)
 
-        w, h = int((label.width + 8) * 1.3), label.height + 3
-        corner = h / 3
-        label.x = corner + 8
+        corner = (label.height + 3) / 3
+        label.x = corner + 6
+        w, h = int(label.x + label.width + label.height * 0.3), label.height + 3
 
         self.color = color
 
